import Ember from 'ember';
import SelectPickerMixin from 'ember-cli-select-picker/mixins/select-picker';

var I18nProps = (Ember.I18n && Ember.I18n.TranslateableProperties) || {};

var SelectPickerComponent = Ember.Component.extend(
  SelectPickerMixin, I18nProps, {

  prompt:          'Nothing Selected',
  summaryMessage:  '%@ items selected',
  selectAllLabel:  'All',
  selectNoneLabel: 'None',

  nativeMobile: true,

  classNames: ['select-picker'],

  badgeEnabled: Ember.computed.and('showBadge', 'multiple'),
  selectionBadge: Ember.computed(
    'selection.length', 'badgeEnabled',
    function() {
      var enabled = this.get('badgeEnabled');
      var selected = this.get('selection.length');
      return (enabled && selected && selected !== 0) ? selected : "";
    }
  ),

  setupDom: Ember.on('didInsertElement', function() {
    var eventName = 'click.' + this.get('elementId');
    var _this = this;
    $(document).on(eventName, function (e) {
      if (_this.get('keepDropdownOpen')) {
        _this.set('keepDropdownOpen', false);
        return;
      }
      if (_this.element && !$.contains(_this.element, e.target)) {
        _this.set('showDropdown', false);
      }
    });
  }),

  teardownDom: Ember.on('willDestroyElement', function() {
    $(document).off('.' + this.get('elementId'));
  }),

  actions: {
    showHide: function () {
      this.toggleProperty('showDropdown');
    },
    closeDropdown: function() {
      this.set('showDropdown', false);
    }
  }
});

export default SelectPickerComponent;
